import json

from qtpy.QtCore import *

import creaturecast_designer.models.abstract_models as abm
import py_maya_core.utilities as mut
import py_maya_core.models.data_models as dmd
import py_maya_core.models.session as ses


class NodeLibraryModel(abm.TableModel):

    error = Signal()

    def __init__(self, *args, **kwargs):

        super(NodeLibraryModel, self).__init__(*args, **kwargs)


    def mimeTypes(self):
        return ['application/py_nodes']

    def mimeData(self, indexes):
        mimedata = QMimeData()
        nodes = [self.get_item(x) for x in indexes]
        mimedata.setData(
                'application/py_nodes',
                json.dumps(mut.serialize_nodes(*nodes))
        )
        self.drag_items = nodes
        self.dataChanged.emit(indexes[0], indexes[-1])
        return mimedata

    def dropMimeData(self, mimedata, action, row, column, parent_index):
        print 'foo'
        if mimedata.hasFormat('application/py_nodes'):
            mime_data = json.loads(str(mimedata.data('application/py_nodes')))
            for x in mime_data:
                tool = dmd.DatabaseTool(**x)
                print row, column
                self._data[row][column] = tool
                ses.session.add(tool)
            ses.session.commit()

        self.dataChanged.emit(parent_index, parent_index)

        return True




from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *

class PortCircle(QtWidgets.QGraphicsWidget):

    __radius = 4.5
    __diameter = 2 * __radius

    def __init__(self, port, graph, hOffset, color, connectionPointType):
        super(PortCircle, self).__init__(port)

        self.__port = port
        self._graph = graph
        self._connectionPointType = connectionPointType
        self.__connections = set()
        self._supportsOnlySingleConnections = connectionPointType == 'In'

        self.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed))
        size = QtCore.QSizeF(self.__diameter, self.__diameter)
        self.setPreferredSize(size)
        self.setWindowFrameMargins(0, 0, 0, 0)

        self.transform().translate(self.__radius * hOffset, 0)

        self.__defaultPen = QtGui.QPen(QtGui.QColor(25, 25, 25), 1.0)
        self.__hoverPen = QtGui.QPen(QtGui.QColor(255, 255, 100), 1.5)

        self._ellipseItem = QtWidgets.QGraphicsEllipseItem(self)
        self._ellipseItem.setPen(self.__defaultPen)
        self._ellipseItem.setPos(size.width()/2, size.height()/2)
        self._ellipseItem.setRect(
            -self.__radius,
            -self.__radius,
            self.__diameter,
            self.__diameter,
            )
        if connectionPointType == 'In':
            self._ellipseItem.setStartAngle(270 * 16)
            self._ellipseItem.setSpanAngle(180 * 16)

        self.setColor(color)
        self.setAcceptHoverEvents(True)

    def getPort(self):
        return self.__port


    def getColor(self):
        return self.getPort().getColor()


    def centerInSceneCoords(self):
        return self._ellipseItem.mapToScene(0, 0)


    def setColor(self, color):
        self._color = color
        self._ellipseItem.setBrush(QtGui.QBrush(self._color))


    def setDefaultPen(self, pen):
        self.__defaultPen = pen
        self._ellipseItem.setPen(self.__defaultPen)


    def setHoverPen(self, pen):
        self.__hoverPen = pen


    def highlight(self):
        self._ellipseItem.setBrush(QtGui.QBrush(self._color.lighter()))
        # make the port bigger to highlight it can accept the connection.
        self._ellipseItem.setRect(
            -self.__radius * 1.3,
            -self.__radius * 1.3,
            self.__diameter * 1.3,
            self.__diameter * 1.3,
            )


    def unhighlight(self):
        self._ellipseItem.setBrush(QtGui.QBrush(self._color))
        self._ellipseItem.setRect(
            -self.__radius,
            -self.__radius,
            self.__diameter,
            self.__diameter,
            )


    # ===================
    # Connection Methods
    # ===================
    def connectionPointType(self):
        return self._connectionPointType

    def isInConnectionPoint(self):
        return self._connectionPointType == 'In'

    def isOutConnectionPoint(self):
        return self._connectionPointType == 'Out'

    def supportsOnlySingleConnections(self):
        return self._supportsOnlySingleConnections

    def setSupportsOnlySingleConnections(self, value):
        self._supportsOnlySingleConnections = value

    def canConnectTo(self, otherPortCircle):

        if self.connectionPointType() == otherPortCircle.connectionPointType():
            return False

        if self.getPort().getDataType() != otherPortCircle.getPort().getDataType():
            return False

        # Check if you're trying to connect to a port on the same node.
        # TODO: Do propper cycle checking..
        otherPort = otherPortCircle.getPort()
        port = self.getPort()
        if otherPort.getNode() == port.getNode():
            return False

        return True

    def addConnection(self, connection):
        """Adds a connection to the list.
        Arguments:
        connection -- connection, new connection to add.
        Return:
        True if successful.
        """

        if self._supportsOnlySingleConnections and len(self.__connections) != 0:
            # gather all the connections into a list, and then remove them from the graph.
            # This is because we can't remove connections from ports while
            # iterating over the set.
            connections = []
            for c in self.__connections:
                connections.append(c)
            for c in connections:
                self._graph.removeConnection(c)

        self.__connections.add(connection)

        return True

    def removeConnection(self, connection):
        """Removes a connection to the list.
        Arguments:
        connection -- connection, connection to remove.
        Return:
        True if successful.
        """

        self.__connections.remove(connection)

        return True

    def getConnections(self):
        """Gets the ports connections list.
        Return:
        List, connections to this port.
        """

        return self.__connections

    # ======
    # Events
    # ======
    def hoverEnterEvent(self, event):
        self.highlight()
        super(PortCircle, self).hoverEnterEvent(event)


    def hoverLeaveEvent(self, event):
        self.unhighlight()
        super(PortCircle, self).hoverLeaveEvent(event)

    def mousePressEvent(self, event):

        self.unhighlight()

        scenePos = self.mapToScene(event.pos())

        from .mouse_grabber import MouseGrabber
        if self.isInConnectionPoint():
            MouseGrabber(self._graph, scenePos, self, 'Out')
        elif self.isOutConnectionPoint():
            MouseGrabber(self._graph, scenePos, self, 'In')


    # def paint(self, painter, option, widget):
    #     super(PortCircle, self).paint(painter, option, widget)
    #     painter.setPen(QtGui.QPen(QtGui.QColor(255, 255, 0)))
    #     painter.drawRect(self.windowFrameRect())


class ItemHolder(QtWidgets.QGraphicsWidget):
    """docstring for ItemHolder"""
    def __init__(self, parent):
        super(ItemHolder, self).__init__(parent)

        layout = QtWidgets.QGraphicsLinearLayout()
        layout.setSpacing(0)
        layout.setContentsMargins(0, 0, 0, 0)
        self.setLayout(layout)

    def setItem(self, item):
        item.setParentItem(self)
        self.layout().addItem(item)

    # def paint(self, painter, option, widget):
    #     super(ItemHolder, self).paint(painter, option, widget)
    #     painter.setPen(QtGui.QPen(QtGui.QColor(255, 255, 0)))
    #     painter.drawRect(self.windowFrameRect())



class BasePort(QtWidgets.QGraphicsWidget):

    _labelColor = QtGui.QColor(25, 25, 25)
    _labelHighlightColor = QtGui.QColor(225, 225, 225, 255)

    def __init__(self, parent, graph, name, color, dataType, connectionPointType):
        super(BasePort, self).__init__(parent)

        self._node = parent
        self._graph = graph
        self._name = name
        self._dataType = dataType
        self._connectionPointType = connectionPointType

        self.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed))

        layout = QtWidgets.QGraphicsLinearLayout()
        layout.setSpacing(0)
        layout.setContentsMargins(0, 0, 0, 0)
        self.setLayout(layout)

        self._color = color

        self._inCircle = None
        self._outCircle = None
        self._labelItem = None

        self._inCircleHolder = ItemHolder(self)
        self._outCircleHolder = ItemHolder(self)
        self._labelItemHolder = ItemHolder(self)

        self.layout().addItem(self._inCircleHolder)
        self.layout().setAlignment(self._inCircleHolder, QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter)

        self.layout().addItem(self._labelItemHolder)
        self.layout().setAlignment(self._labelItemHolder, QtCore.Qt.AlignHCenter | QtCore.Qt.AlignVCenter)

        self.layout().addItem(self._outCircleHolder)
        self.layout().setAlignment(self._outCircleHolder, QtCore.Qt.AlignRight | QtCore.Qt.AlignVCenter)


    def getName(self):
        return self._name


    def getDataType(self):
        return self._dataType


    def getNode(self):
        return self._node


    def getGraph(self):
        return self._graph


    def getColor(self):
        return self._color


    def setColor(self, color):
        if self._inCircle is not None:
            self._inCircle.setColor(color)
        if self._outCircle is not None:
            self._outCircle.setColor(color)
        self._color = color


    def inCircle(self):
        return self._inCircle


    def setInCircle(self, inCircle):
        self._inCircleHolder.setItem(inCircle)
        self._inCircle = inCircle
        self.layout().insertStretch(2, 2)
        self.updatecontentMargins()

    def outCircle(self):
        return self._outCircle


    def setOutCircle(self, outCircle):
        self._outCircleHolder.setItem(outCircle)
        self._outCircle = outCircle
        self.layout().insertStretch(1, 2)
        self.updatecontentMargins()

    def updatecontentMargins(self):
        left = 0
        right = 0
        if self._inCircle is None:
            left = 30
        if self._outCircle is None:
            right = 30
        self.layout().setContentsMargins(left, 0, right, 0)


    def labelItem(self):
        return self._labelItem


    def setLabelItem(self, labelItem):
        self._labelItemHolder.setItem(labelItem)
        self._labelItem = labelItem


    # ===================
    # Connection Methods
    # ===================
    def connectionPointType(self):
        return self._connectionPointType

    # def paint(self, painter, option, widget):
    #     super(BasePort, self).paint(painter, option, widget)
    #     painter.setPen(QtGui.QPen(QtGui.QColor(255, 255, 0)))
    #     painter.drawRect(self.windowFrameRect())


class InputPort(BasePort):

    def __init__(self, parent, graph, name, color, dataType):
        super(InputPort, self).__init__(parent, graph, name, color, dataType, 'In')

        self.setInCircle(PortCircle(self, graph, -2, color, 'In'))
        self.setLabelItem(PortLabel(self, name, -10, self._labelColor, self._labelHighlightColor))



class OutputPort(BasePort):

    def __init__(self, parent, graph, name, color, dataType):
        super(OutputPort, self).__init__(parent, graph, name, color, dataType, 'Out')

        self.setLabelItem(PortLabel(self, self._name, 10, self._labelColor, self._labelHighlightColor))
        self.setOutCircle(PortCircle(self, graph, 2, color, 'Out'))



class IOPort(BasePort):

    def __init__(self, parent, graph, name, color, dataType):
        super(IOPort, self).__init__(parent, graph, name, color, dataType, 'IO')

        self.setInCircle(PortCircle(self, graph, -2, color, 'In'))
        self.setLabelItem(PortLabel(self, self._name, 0, self._labelColor, self._labelHighlightColor))
        self.setOutCircle(PortCircle(self, graph, 2, color, 'Out'))





import os
import requests
import json
import shutil
from os.path import expanduser
import creaturecast_designer.services as svc

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%screaturecast' % home_directory


def get_image(local_path, always_download=False):

    url = '%s/get_image' % svc.library_url

    data = dict(local_path=local_path)
    path = '%s%s' % (creaturecast_directory, local_path)
    if os.path.exists(path) and not always_download:
        return path
    else:
        response = requests.post(
            url,
            data=json.dumps(data),
            headers={'Content-Type': 'application/json'},
            stream=True
        )
        if response.status_code == 200:
            dirname = os.path.dirname(path)
            try:
                os.makedirs(dirname)
            except:
                pass
            with open(path, 'wb') as f:
                response.raw.decode_content = True
                shutil.copyfileobj(response.raw, f)
                return path


if __name__ == '__main__':
    get_image('/python.png')


import os
import requests
import json
import shutil
import time
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
from os.path import expanduser
import creaturecast_designer.media as media

package_name = __file__.replace('\\', '/').split('/')[-2]
home_directory = expanduser("~").replace('\\', '/')
local_user = os.getenv('USER')
creaturecast_directory = '%s/creaturecast' % home_directory

icon_cache = dict()
empty_icon_path = media.get_icon_path('empty')


pixmaps = dict()











def get_icon(key):
    if key in icon_cache:
        return icon_cache[key]
    else:
        icon_path = media.get_icon_path(key)
        if not os.path.exists(icon_path):
            icon_path = media.get_icon_path('empty')
        new_icon = QIcon(icon_path)
        icon_cache['key'] = new_icon
        return new_icon






from os.path import expanduser
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *

import creaturecast_designer.widgets.progress_indicator as prg
import creaturecast_designer.widgets.avatar_label as avl
import creaturecast_designer.services.download_image as dim
import creaturecast_designer.services.thread_worker as wkr
import creaturecast_designer.environment as env

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory

class UserWidget(QFrame):

    log_out = Signal()
    def __init__(self, *args, **kwargs):
        super(UserWidget, self).__init__(*args, **kwargs)

        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)

        self.vertical_layout = QVBoxLayout(self)
        self.horizontal_layout = QHBoxLayout()
        self.label_layout = QVBoxLayout()
        self.button_layout = QHBoxLayout()

        self.avatar_label = avl.AvatarLabel(self)
        self.avatar_label.set_image_size(QSize(128, 128))

        self.user_label = QLabel(self)
        self.log_out_button = QPushButton('Log Out', self)
        self.avatar_label.setAlignment(Qt.AlignCenter)
        self.user_label.setAlignment(Qt.AlignCenter)

        self.font = QFont('', 18, True)
        self.button_font = QFont('', 12, False)

        self.user_label.setFont(self.font)
        self.log_out_button.setFont(self.button_font)

        self.busy_widget = prg.QProgressIndicator(self)
        self.busy_widget.setAnimationDelay(70)
        self.busy_widget.setVisible(True)
        self.busy_widget.startAnimation()
        self.horizontal_layout.addLayout(self.vertical_layout)

        self.vertical_layout.addLayout(self.label_layout)
        self.vertical_layout.addStretch()

        self.label_layout.addStretch()
        self.label_layout.addWidget(self.avatar_label)
        self.label_layout.addWidget(self.user_label)
        self.button_layout.addStretch()
        self.button_layout.addWidget(self.log_out_button)
        self.button_layout.addStretch()
        self.label_layout.addSpacerItem(QSpacerItem(20, 20))
        self.label_layout.addLayout(self.button_layout)
        self.label_layout.addStretch()
        self.log_out_button.pressed.connect(self.log_out)
        env.user_handler.user_changed.connect(self.set_user)

    def set_user(self, data):
        if data['given_name'] and data['family_name']:
            self.user_label.setText('%s %s' % (data['given_name'], data['family_name']))
        else:
            self.user_label.setText(data['email'])

        avatar_path = data['avatar']
        exrension = avatar_path.split('.')[-1]
        self.worker = wkr.FunctionWorker(
            dim.download_image,
            data['avatar'],
            '%s.%s' % (data['token'], exrension),
            always_download=True
        )
        self.thread = QThread()
        self.thread.start()
        self.worker.moveToThread(self.thread)
        self.worker.start.connect(self.worker.run)
        self.worker.data.connect(self.avatar_label.set_image)
        self.worker.start.emit()



import sys
import widgets.designer_widget as dwd
from qtpy.QtWidgets import QApplication
import services.get_stylesheet as stl

app = QApplication(sys.argv)
app.setStyleSheet(stl.get_stylesheet('slate'))
mainWin = dwd.DesignerWindow()
mainWin.show()
sys.exit(app.exec_())


import json
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
import creaturecast_designer.models.sidebar_model as sbm
import creaturecast_designer.services.list_extensions as lex
import creaturecast_designer.services.thread_worker as thd
import creaturecast_designer.widgets.progress_indicator as prg
import creaturecast_designer.environment as env
dock_options = QMainWindow.AnimatedDocks | QMainWindow.AllowNestedDocks | QMainWindow.AllowTabbedDocks | QMainWindow.VerticalTabs
#| QMainWindow.AllowNestedDocks | QMainWindow.AllowTabbedDock


class SidebarWidget(QWidget):
    item_indent_spaces = 4
    item_selection = Signal(list)
    log_out = Signal()

    def __init__(self, *args, **kwargs):
        super(SidebarWidget, self).__init__(*args, **kwargs)

        self.vertical_layout = QVBoxLayout(self)
        self.list_view = SideBarView(self)
        self.list_view.setSelectionMode(QAbstractItemView.ExtendedSelection)
        self.list_view.setSelectionBehavior(QAbstractItemView.SelectRows)
        self.list_view.setIconSize(QSize(32, 32))
        self.list_view.setSpacing(2)
        self.dock_widgets = {}

        self.vertical_layout.addWidget(self.list_view)
        self.setContentsMargins(0, 0, 0, 0)
        self.list_view.setContentsMargins(0, 0, 0, 0)
        self.vertical_layout.setContentsMargins(0, 0, 0, 0)
        self.setMaximumWidth(215)
        self.setMinimumWidth(215)

        self.busy_widget = prg.QProgressIndicator(self)
        self.busy_widget.setAnimationDelay(70)
        self.busy_widget.setVisible(False)

        self.extensions_worker = None
        self.extensions_thread = None

        self.list_view.item_selection.connect(self.item_selection.emit)

        self.list_view.setModel(sbm.SidebarModel([]))

        env.user_handler.user_changed.connect(self.load_extensions)

    def load_extensions(self, user_data):
        print 'SIDEBAR', user_data['settings']['extensions']
        model = sbm.SidebarModel([])
        filter_model = sbm.ToolFilterModel(user_data['settings']['extensions'])
        filter_model.setSourceModel(model)

        self.list_view.setModel(filter_model)

        self.busy_widget.setVisible(True)
        self.busy_widget.startAnimation()

        self.extensions_worker = thd.GeneratorWorker(lex.list_extensions)
        self.extensions_thread = QThread()
        self.extensions_thread.start()
        self.extensions_worker.moveToThread(self.extensions_thread)
        self.extensions_worker.data.connect(self.create_item)
        self.extensions_worker.success.connect(self.end_loading)
        self.extensions_worker.start.connect(self.extensions_worker.run)
        self.extensions_worker.start.emit()

    def end_loading(self):
        self.busy_widget.setVisible(False)

    def create_item(self, json_string):
        self.list_view.get_model().add_item(json.loads(json_string))
        proxy_model = self.list_view.model()
        proxy_model.reset()

    def resizeEvent(self, event):
        self.busy_widget.resize(event.size())
        event.accept()

class SideBarView(QListView):

    item_selection = Signal(list)

    def __init__(self, *args, **kwargs):
        super(SideBarView, self).__init__(*args, **kwargs)
        self.setFocusPolicy(Qt.NoFocus)

    def setModel(self, model):
        super(SideBarView, self).setModel(model)
        if model:
            selectionModel = self.selectionModel()
            selectionModel.selectionChanged.connect(self.emit_selected_items)

    def emit_selected_items(self, *args):
        model = self.model()
        new_selection, old_selection = args

        old_indices = [i for i in self.selectedIndexes() if i.column() == 0]
        new_indices = [i for i in new_selection.indexes() if i.column() == 0]
        self.item_selection.emit([model.get_item(x) for x in old_indices])

    def get_model(self):
        model = self.model()
        while isinstance(model, QSortFilterProxyModel):
            model = model.sourceModel()
        return model

class SideBarItem(object):
    def __init__(self, **kwargs):
        super(SideBarItem, self).__init__()
        self.data = dict(kwargs)
        self.dock_widget = None

    def __str__(self):
        return self.data['name']

    def __repr__(self):
        return self.__str__()




from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *


import creaturecast_designer.media as med



class LoadingPage(QWidget):

    create_rig_component = Signal(dict)

    def __init__(self, *args, **kwargs):
        super(LoadingPage, self).__init__(*args, **kwargs)


        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        self.horizontal_layout = QHBoxLayout(self)
        self.vertical_layout = QVBoxLayout()
        self.horizontal_layout.setAlignment(Qt.AlignCenter)
        self.icon_label = QLabel('', self)
        default_image = QImage(med.get_icon_path('clock'))
        default_pixmap = QPixmap.fromImage(default_image.scaled(45, 45, Qt.IgnoreAspectRatio, Qt.SmoothTransformation))
        self.icon_label.setPixmap(default_pixmap)
        self.icon_label.setAlignment(Qt.AlignCenter);
        self.message_label = QLabel('   loading...', self)
        self.message_label.setAlignment(Qt.AlignCenter);
        self.message_font = QFont("arial", 22, True)
        self.message_font.setWeight(15)
        self.message_font.setBold(False)
        self.message_font.setLetterSpacing(QFont.PercentageSpacing, 100)
        self.message_label.setFont(self.message_font)
        self.horizontal_layout.addLayout(self.vertical_layout)
        self.vertical_layout.addItem(
            QSpacerItem(55, 55)
        )
        self.vertical_layout.addWidget(self.icon_label)
        self.vertical_layout.addWidget(self.message_label)
        self.vertical_layout.addStretch()

    def resizeEvent(self, event):
        self.busy_widget.resize(event.size())
        event.accept()



import os
import creaturecast_designer
root_package_directory = os.path.dirname(creaturecast_designer.__file__.replace('\\', '/'))
icon_directory = '%s/media/icons' % root_package_directory
image_directory = '%s/media/images' % root_package_directory

def get_icon_path(key):
    return '%s/%s.png' % (icon_directory, key)

def get_image_path(key):
    return '%s/%s.png' % (image_directory, key)



import urllib
import os
from os.path import expanduser

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory


def download_image(url, file_name, always_download=True):

    path = '%s/images/%s' % (creaturecast_directory, file_name)
    if os.path.exists(path) and not always_download:
        return path
    image_opener = urllib.URLopener()
    image_opener.retrieve(url, path)

    return path



class GitFetchWorker(QThread):

    update_progress = Signal(int)
    failed = Signal()
    success = Signal()
    def __init__(self, *args, **kwargs):
        self.git_url = str(args[0])
        QThread.__init__(self)

    def run(self):

        import git
        from git import RemoteProgress

        module_name = self.git_url.split('/')[-1].split('.')[0]
        package_directory = '%s/%s' % (env.modules_directory, module_name)
        outdir_checker = package_directory + '/.git'

        class ProgressHandler(RemoteProgress):
            update_progress = PySignal.ClassSignal()

            def __init__(self, signal, *args, **kwargs):
                self.signal = signal
                super(ProgressHandler, self).__init__(*args, **kwargs)

            def update(self, op_code, cur_count, max_count=None, message=''):
                self.signal.emit(int(float(cur_count) / (max_count or 100.0) * 100))

        progress_handler = ProgressHandler(self.update_progress)


        if os.path.exists(outdir_checker):
            #repo_worker = git.Repo.init(package_directory)
            #repo_worker.git.reset('--hard')
            #repo_worker.git.clean('-fdx')
            #remotes = repo_worker.remotes
            #for r in remotes:
            #    o = r.origin
            #    o.pull(progress=progress_handler)
            self.success.emit()

        if not os.path.exists(outdir_checker):
            shutil.rmtree(package_directory, ignore_errors=True)
            os.makedirs(package_directory)
            try:
                git.Repo.clone_from(self.git_url, package_directory, progress=progress_handler)
            except:
                self.failed.emit()
                print 'Failed to clone repo. There seems to be a problem with the network connection'
            print('git dir created')


class UninstallWorker(QThread):

    failed = Signal()
    success = Signal()

    def __init__(self, *args, **kwargs):
        self.package_directory = copy.copy(str(args[0]))
        QThread.__init__(self)

    def run(self):
        if not os.path.exists(self.package_directory):
            self.success.emit()
        #clear_dir(self.package_directory)
        self.success.emit()



from qtpy.QtCore import *
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *

import creaturecast_designer.media as med
from os.path import expanduser
home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory


class AvatarLabel(QLabel):
    def __init__(self, *args, **kwargs):
        super(AvatarLabel, self).__init__(*args, **kwargs)
        self.image_size = QSize(32, 32)
        self.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)

    def set_image_size(self, size):
        self.image_size = size
        self.set_image(med.get_icon_path('generic_user'))

    def sizeHint(self, *args, **kwargs):
        return self.image_size

    def set_image(self, path):
        height = self.image_size.height()
        width = self.image_size.width()

        user_image = QImage(path)

        alpha_image = QImage(med.get_icon_path('circle_alpha'))

        alpha_image = alpha_image.scaled(
            height,
            width,
            Qt.IgnoreAspectRatio,
            Qt.SmoothTransformation
        )

        user_image = user_image.scaled(
            height,
            width,
            Qt.IgnoreAspectRatio,
            Qt.SmoothTransformation
        )

        user_image.setAlphaChannel(alpha_image)
        user_pixmap = QPixmap.fromImage(user_image)

        self.setPixmap(user_pixmap)



import os
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
from qtpy.QtWebEngineWidgets import *

import string
import random
import creaturecast_designer.services as svc
import creaturecast_designer.services.thread_worker as wrk
import creaturecast_designer.services.get_user_data as gud
import creaturecast_designer.widgets.pixmap_label as pxl
import creaturecast_designer.environment as env

#include <QtGui>
#include <QtWebKit>


def random_string_generator(size=48, chars=string.ascii_uppercase + string.digits):
    return ''.join(random.choice(chars) for x in range(size))


class LoginWidget(QFrame):

    facebook_pin = random_string_generator()
    google_pin = random_string_generator()
    start_login = Signal()

    def __init__(self, *args, **kwargs):
        super(LoginWidget, self).__init__(*args, **kwargs)
        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        self.setAutoFillBackground(True)
        self.icon_label = pxl.PixmapLabel('/images/Creaturecast.png', self)
        self.icon_label.setAlignment(Qt.AlignCenter)

        self.google_login_button = ButtonLabel(
            '/images/sign_in_google.png',
            always_download=True,
            parent=self
        )
        self.google_login_button.setAlignment(Qt.AlignCenter)

        self.vertical_layout = QVBoxLayout(self)
        self.horizontal_layout = QHBoxLayout()
        self.button_layout = QVBoxLayout()

        self.horizontal_layout.addLayout(self.vertical_layout)
        self.vertical_layout.addItem(
            QSpacerItem(55, 55)
        )
        self.vertical_layout.addWidget(self.icon_label)
        self.vertical_layout.addLayout(self.horizontal_layout)

        self.horizontal_layout.addStretch()
        self.horizontal_layout.addLayout(self.button_layout)
        self.horizontal_layout.addStretch()

        self.button_layout.addWidget(self.google_login_button)
        self.button_layout.addStretch()
        self.google_login_button.pressed.connect(self.google_login)


    def google_login(self):

        token = env.settings.get('token', None)
        if token:
            self.start_login.emit()
            self.google_worker = wrk.FunctionWorker(gud.get_user_data, token, pause=0.1)
            self.google_thread = QThread()
            self.google_thread.start()
            self.google_worker.moveToThread(self.google_thread)
            self.google_worker.data.connect(self.emit_login)
            self.google_worker.start.connect(self.google_worker.run)
            self.google_worker.start.emit()
        else:
            self.start_login.emit()
            url = '%s/login?temporary_pin=%s' % (svc.library_url, self.google_pin)
            os.startfile(url)
            self.google_worker = wrk.FunctionWorker(gud.get_user_data, self.google_pin, pause=0.1)
            self.google_thread = QThread()
            self.google_thread.start()
            self.google_worker.moveToThread(self.google_thread)
            self.google_worker.data.connect(self.emit_login)
            self.google_worker.start.connect(self.google_worker.run)
            self.google_worker.start.emit()

    def emit_login(self, user_data):
        env.settings['token'] = user_data['token']
        env.settings['email'] = user_data['email']
        env.user_handler.set_user(user_data)


class ButtonLabel(pxl.PixmapLabel):
    pressed = Signal()

    def __init__(self, *args, **kwargs):
        super(ButtonLabel, self).__init__(*args, **kwargs)

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.pressed.emit()


class WebDialog(QDialog):
    def __init__(self, *args, **kwargs):
        super(WebDialog, self).__init__(*args, **kwargs)
        self.layout = QHBoxLayout(self)
        self.web_view = QWebEngineView(self)
        self.layout.addWidget(self.web_view)


if __name__ == '__main__':
    import sys
    app = QApplication(sys.argv)
    widget = LoginWidget()
    widget.show()
    sys.exit(app.exec_())



import os
import requests
import json
import shutil
from os.path import expanduser
import creaturecast_designer.services as svc

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%screaturecast' % home_directory
stylesheets_directory = '%s/stylesheets' % creaturecast_directory


def get_stylesheet(stylesheet, always_download=False):

    stylesheet_path = '%s/%s.qss' % (stylesheets_directory, stylesheet)
    if os.path.exists(stylesheet_path) and not always_download:
        with open(stylesheet_path, mode='r') as f:
            return f.read()

    url = '%s/get_stylesheet' % svc.library_url

    data = dict(stylesheet=stylesheet)

    response = requests.post(
        url,
        data=json.dumps(data),
        headers={'Content-Type': 'application/json'},
        stream=True
    )
    if response.status_code == 200:
        dirname = os.path.dirname(stylesheet_path)
        try:
            os.makedirs(dirname)
        except:
            pass
        stylesheet_text = response.text
        with open(stylesheet_path, 'w') as f:
            f.write(stylesheet_text)
        return stylesheet_text


if __name__ == '__main__':
    print get_stylesheet('slate')



import os
import platform
from os.path import expanduser
from qtpy.QtCore import *
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
import creaturecast_designer.services.download_image as dim
import creaturecast_designer.services.thread_worker as wkr
import creaturecast_designer.widgets.progress_indicator as prg
import creaturecast_designer.widgets.avatar_label as alb
import creaturecast_designer.environment as env

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory

class UserHeader(QWidget):

    clicked = Signal()


    def __init__(self, *args, **kwargs):
        super(UserHeader, self).__init__(*args, **kwargs)
        self.layout = QHBoxLayout(self)
        self.avatar_label = alb.AvatarLabel(self)
        self.avatar_label.set_image_size(QSize(32, 32))
        self.user_label = QLabel('Log Out', parent=self)

        self.font = QFont('', 9, False)
        self.user_label.setFont(self.font)
        #self.user_label.setStyleSheet("QLabel{background:transparent}")

        self.layout.addWidget(self.avatar_label)
        self.layout.addWidget(self.user_label)
        self.layout.addStretch()

        self.busy_widget = prg.QProgressIndicator(self)
        self.busy_widget.setAnimationDelay(70)
        self.busy_widget.setVisible(True)
        self.busy_widget.startAnimation()
        self.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        self.busy_widget.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        self.user_label.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        self.avatar_label.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        env.user_handler.user_changed.connect(self.set_user)
        self.user_data = None

    def set_user(self, data):
        self.user_data = data
        if data['given_name'] and data['family_name']:
            self.user_label.setText('%s %s' % (data['given_name'], data['family_name']))
        else:
            self.user_label.setText(data['email'])
        self.thread = QThread()
        self.thread.start()
        avatar_path = data['avatar']
        exrension = avatar_path.split('.')[-1]

        self.worker = wkr.FunctionWorker(
            dim.download_image,
            data['avatar'],
            '%s.%s' % (data['temporary_pin'], exrension),
            always_download=True
        )
        self.worker.moveToThread(self.thread)
        self.worker.start.connect(self.worker.run)
        self.worker.data.connect(self.set_avatar_image)
        self.worker.start.emit()

    def set_avatar_image(self, path):
        user_image = QImage(path)
        if user_image.isNull() or not os.path.exists(path):
            self.set_user(self.user_data)
        else:
            self.avatar_label.set_image(path)

    def mousePressEvent(self, *args, **kwargs):
        self.clicked.emit()

def get_temp_path():
    if platform.system() in ['Darwin','Linux']:
        return os.getenv('TMPDIR').replace('\\', '/')
    else:
        return os.getenv('TEMP').replace('\\', '/')



import collections
from qtpy.QtCore import *


class GeneratorWorker(QObject):

    start = Signal()
    data = Signal(object)
    failed = Signal()
    success = Signal()
    end = Signal()

    def __init__(self, generator, *args, **kwargs):
        super(GeneratorWorker, self).__init__()
        self.generator = generator
        self.args = args
        self.kwargs = kwargs

    @Slot()
    def run(self):
        for x in self.generator(*self.args, **self.kwargs):
            self.data.emit(x)
            self.success.emit()


class FunctionWorker(QObject):

    start = Signal()
    data = Signal(object)
    failed = Signal()
    success = Signal()
    end = Signal()

    def __init__(self, worker_function, *args, **kwargs):
        super(FunctionWorker, self).__init__()
        self.worker_function = worker_function
        self.args = args
        self.kwargs = kwargs

    @Slot()
    def run(self):
        return_value = self.worker_function(*self.args, **self.kwargs)
        self.data.emit(return_value)
        self.success.emit()
        self.end.emit()





import pip
import subprocess


def pip_install(package_name, version=None):
    # subprocess.check_output(['ls','-l']) #all that is technically needed...
    print subprocess.check_output(['pip', 'install', package_name])
    return package_name


import os
import requests
import json
import shutil
from qtpy.QtCore import *
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
from os.path import expanduser
import creaturecast_designer.media as media
from creaturecast_designer.widgets.progress_widget import ProgressWidget

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory
empty_tool_path = media.get_image_path('empty_tool')
import creaturecast_designer.services as svc
import creaturecast_designer.services.get_image as gmg
import creaturecast_designer.services.thread_worker as twk

pixmaps = dict()


class PixmapLabel(QLabel):

    def __init__(self, local_path, always_download=True, *args, **kwargs):
        super(PixmapLabel, self).__init__(*args, **kwargs)

        self.busy_widget = ProgressWidget(self)
        self.busy_widget.setAnimationDelay(70)
        self.busy_widget.setVisible(False)
        image_path = '%s%s' % (creaturecast_directory, local_path)

        if os.path.exists(image_path):
            self.setPixmap(QPixmap(image_path))
        else:
            self.setPixmap(QPixmap(empty_tool_path))
            self.busy_widget.setVisible(True)
            self.busy_widget.startAnimation()

            self.worker = twk.FunctionWorker(gmg.get_image, local_path)
            self.thread = QThread()
            self.thread.start()
            self.worker.moveToThread(self.thread)
            self.worker.start.connect(self.worker.run)
            self.worker.data.connect(self.load_pixmap)
            self.worker.start.emit()

    def load_pixmap(self, path):
        self.setPixmap(QPixmap(path))
        self.busy_widget.setVisible(False)

    def resizeEvent(self, event):
        self.busy_widget.resize(event.size())
        event.accept()



import copy

from qtpy.QtCore import *
import creaturecast_designer.widgets.icon as ico
import py_maya_core.node as nod


class AbstractTreeModel(QAbstractItemModel):
    def __init__(self, *args):
        super(AbstractTreeModel, self).__init__()
        self.root = args[0]

    def rowCount(self, index):
        item = self.get_item(index)
        return len(item.children)

    def columnCount(self, index):
        return 1

    def index(self, row, column, parent_index):
        if not self.hasIndex(row, column, parent_index):
            return QModelIndex()

        parent = self.get_item(parent_index)
        if parent:
            return self.createIndex(row, column, parent.children[row])
        return QModelIndex()

    def data(self, index, role):
        item = self.get_item(index)

        if index.column() == 0:

            if role == Qt.DisplayRole or role == Qt.EditRole:
                return item.data['name']

            if role == Qt.DecorationRole:
                if isinstance(item, nod.Node):
                    return ico.get_icon('animal_fly')

    def flags(self, index):
        if not index.isValid():
            return Qt.ItemIsEnabled
        return Qt.ItemIsEnabled | Qt.ItemIsDropEnabled | Qt.ItemIsDragEnabled | Qt.ItemIsSelectable

    def get_item(self, index):
        return index.internalPointer() if index.isValid() else self.root


class TreeModel(AbstractTreeModel):

    def __init__(self, *args):
        super(TreeModel, self).__init__(*args)
        self.index_dictionary = dict()

    def get_child_indices(self, index):
        item = self.get_item(index)
        indexes = []
        for itr in range(len(item.children)):
            indexes.append(self.index(itr, 0, index))
        return indexes

    def get_descendants(self, index):
        descendants = []
        for childIndex in self.get_child_indices(index):
            descendants.append(childIndex)
            descendants.extend(self.get_descendants(childIndex))
        return descendants

    def get_ancestors(self, index):
        indices = []
        while self.get_item(index) is not self.root:
            indices.append(index.parent())
            index = index.parent()
        return indices

    def items_from_indices(self, indices):
        return [self.get_item(x) for x in indices]

    def parent(self, index):
        item = self.get_item(index)
        parent = item.parent
        if parent == self.root:
            return QModelIndex()
        if parent is None:
            return QModelIndex()
        return self.createIndex(parent.get_index(), 0, parent)

    def reset_data(self, index):
        item = self.get_item(index)
        item.data.update(copy.copy(item.default_data))

    def delete_item(self, index):
        node = self.get_item(index)
        parent_index = index.parent()
        row = self.items.index(node)
        self.beginRemoveRows(parent_index, row, row)
        self.items.remove(node)
        self.endRemoveRows()

    def index_from_item(self, item):
        index = QModelIndex()
        for x in item.get_position():
            index = self.index(x, 0, index)
        if item == self.get_item(index):
            return index

class ListModel(QAbstractListModel):

    def __init__(self, items):
        super(ListModel, self).__init__()
        self.items = items

    def rowCount(self, index):
        return len(self.items)

    def columnCount(self, index):
        return 1

    def data(self, index, role):
        item = self.get_item(index)

        if role == Qt.DisplayRole or role == Qt.EditRole:
            return item.data['name']

        if role == Qt.DecorationRole:
            return ico.get_icon(item.data['icon'])

    def flags(self, index):
        return Qt.ItemIsEnabled | Qt.ItemIsDropEnabled | Qt.ItemIsDragEnabled | Qt.ItemIsSelectable

    def delete_item(self, index):
        node = self.get_item(index)
        parent_index = index.parent()
        row = self.items.index(node)
        self.beginRemoveRows(parent_index, row, row)
        self.items.remove(node)
        self.endRemoveRows()

    def get_item(self, index):
        if index.isValid():
            return self.items[index.row()]





class TableModel(QAbstractTableModel):
    def __init__(self, data=[[]], headers=[], parent=None):
        super(TableModel, self).__init__(parent)
        self._data = data
        self.__headers = headers

    def itemFromIndex(self, index):
        return self._data[index.row()][index.column()]

    def rowCount(self, parent):
        return len(self._data)

    def columnCount(self, parent):
        if len(self._data):
            return len(self._data[0])
        return -1

    def flags(self, index):
        #if not index.isValid():
        #    return Qt.ItemIsEnabled
        return Qt.ItemIsEnabled | Qt.ItemIsDropEnabled | Qt.ItemIsDragEnabled | Qt.ItemIsSelectable


    def supportedDropActions(self):
        return Qt.CopyAction | Qt.MoveAction

    def supportedDragActions(self):
        return Qt.MoveAction | Qt.CopyAction

    def data(self, index, role):

        row = index.row()
        column = index.column()
        if row < len(self._data) and column < len(self._data[row]):
            if role == Qt.EditRole:
                row = index.row()
                column = index.column()
                data = self._data[row][column]
                return data

            if role == Qt.ToolTipRole:
                row = index.row()
                column = index.column()
                return  self._data[row][column]

            if role == Qt.DisplayRole:

                row = index.row()
                column = index.column()
                value = self._data[row][column]
                return value

    def setData(self, index, value, role = Qt.EditRole):
        if role == Qt.EditRole:
            row = index.row()
            column = index.column()
            self._data[row][column] = str(value.toString())
            # Why does this throw a warning!!!!!??!

            self.dataChanged.emit(index, index)
            return True
        return False

    def headerData(self, section, orientation, role):

        return None
        if role == Qt.DisplayRole:
            return None
            if orientation == Qt.Horizontal:

                if section < len(self.__headers):
                    return self.__headers[section]
                else:
                    return "not implemented"
            else:
                return None



    #=====================================================#
    #INSERTING & REMOVING
    #=====================================================#
    def insertRows( self, row, count, parentIndex = QModelIndex() ):
        self.beginInsertRows( parentIndex, row, row+count-1 )
        parentItem = self.itemFromIndex(parentIndex)
        print 'Inserting row [%s] under [%s]' % (row, parentItem)
        self.endInsertRows()
        return True

    def insertColumns(self, position, columns, parent = QModelIndex()):
        self.beginInsertColumns(parent, position, position + columns - 1)

        self.endInsertColumns()

        return True

    def moveRows( self, position, count,  parent = QModelIndex()):
        print 'MovingRows...'
        return True
        self.beginRemoveRows(parent, position, position+count-1 )
        for x in range( count ):
            print 'Removing row [%s] under [%s]' % (row, parent)
            self._data.pop(position)
        self.endRemoveRows()
        return True



    def removeRows( self, row, count, parentIndex = QModelIndex()):
        print 'RemovingRows...'
        self.beginRemoveRows( parentIndex, row, row+count-1 )
        for x in range( count ):
            self._data.pop(row)
        self.endRemoveRows()
        return True

    def removeColumns( self, position, count,  parentIndex = QModelIndex()):
        return False


    def removeRow( self, position,  parentIndex = QModelIndex()):
        print 'RemovingRow...'
        return False

    def removeColumn( self, position,  parentIndex = QModelIndex()):
        print 'RemovingColumn..'
        return False



import json
import creaturecast_designer.services as svc
import requests
url = svc.library_url


def update_user_data(token, **kwargs):
    request = requests.post(
        '%s/update_user_data' % url,
        params=dict(
            token=token,
            data=kwargs
        )
    )
    if request.ok:
        json_string = request.text
        response_data = json.loads(json_string)
        if response_data['status'] == 'succeeded':
            return response_data['data']
        else:
            print response_data['message']
    else:
        print request.text
        print 'Failed with error code %s' % request.status_code
        return






import PySignal

class NodeSelecton(object):

    selection_changed = PySignal.ClassSignal()

    def __init__(self):
        super(NodeSelecton, self).__init__()
        self.selected_items = []

    def select_nodes(self, *args):
        self.selected_items = list(args)
        self.selection_changed.emit(self.selected_items)

node_selection = NodeSelecton()





from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
import creaturecast_designer.widgets.icon as ico

class SidebarModel(QAbstractTableModel):

    def __init__(self, items):
        super(SidebarModel, self).__init__()
        self.items = items
        self.title_font = QFont('', 15, True)
        self.item_font = QFont('', 12, False)


    def rowCount(self, index):
        return len(self.items)

    def columnCount(self, index):
        return 2

    def data(self, index, role):
        item = self.get_item(index)
        icon = item['icon']

        if role == Qt.DisplayRole or role == Qt.EditRole:
            return item['name']
        if role == Qt.FontRole:
            if not icon:
                return self.title_font
            else:
                return self.item_font
        if role == Qt.DecorationRole:
            if icon:
                return ico.get_icon(icon)

    def flags(self, index):
        if index.isValid():
            item = self.get_item(index)
            if item['icon']:
                return Qt.ItemIsEnabled | Qt.ItemIsDropEnabled | Qt.ItemIsDragEnabled | Qt.ItemIsSelectable
            return Qt.ItemIsEnabled


    def get_item(self, index):
        if index.isValid():
            return self.items[index.row()]

    def add_item(self, data):
        row = len(self.items)
        self.beginInsertRows(QModelIndex(), row, row+1)
        self.items.append(data)
        self.endInsertRows()


class ToolFilterModel(QSortFilterProxyModel):
    def __init__(self, user_tools, *args, **kwargs):
        super(ToolFilterModel, self).__init__(*args, **kwargs)
        self.setDynamicSortFilter(True)
        self.user_tools = user_tools

    def set_user_tools(self, user_tools):
        self.user_tools = user_tools
        self.invalidateFilter()

    def filterAcceptsRow(self, sourceRow, sourceParent):
        index = self.sourceModel().index(sourceRow, 0, sourceParent)

        if index.isValid():
            tool = self.sourceModel().get_item(index)

            print tool['package']
            print self.user_tools
            if tool['package'] in self.user_tools:
                return True
        return False

    def get_item(self, index):
        source_index = self.mapToSource(index)
        return self.sourceModel().get_item(source_index)



import os
import requests
import json
import shutil
from qtpy.QtCore import *
from qtpy.QtCore import *
from qtpy.QtGui import *
from qtpy.QtWidgets import *
from os.path import expanduser
import extensions_widget.media as media
from extensions_widget.widgets.QProgressIndicator import QProgressIndicator

home_directory = expanduser("~").replace('\\', '/')
creaturecast_directory = '%s/creaturecast' % home_directory
empty_tool_path = media.get_image_path('empty_tool')
library_url = 'https://creaturecast-library.herokuapp.com'

pixmaps = dict()


class PixmapPushButton(QLabel):

    def __init__(self, local_path, *args, **kwargs):
        super(PixmapPushButton, self).__init__(*args, **kwargs)

        self.busy_widget = QProgressIndicator(self)
        self.busy_widget.setAnimationDelay(70)
        self.busy_widget.setVisible(False)
        image_path = '%s%s' % (creaturecast_directory, local_path)

        if os.path.exists(image_path):
            self.setIcon(QIcon(image_path))
        else:
            self.setIcon(QIcon(empty_tool_path))
            self.busy_widget.setVisible(True)
            self.busy_widget.startAnimation()
            self.worker = ImageDownloadWorker(local_path)
            self.thread = QThread()
            self.thread.start()
            self.worker.moveToThread(self.thread)
            self.worker.start.connect(self.worker.run)
            self.worker.finished.connect(self.load_pixmap)
            self.worker.start.emit()

    def load_pixmap(self, path):
        self.setIcon(QIcon(path))
        self.busy_widget.setVisible(False)

    def resizeEvent(self, event):
        self.busy_widget.resize(event.size())
        event.accept()



class ImageDownloadWorker(QObject):

    start = Signal()
    finished = Signal(str)
    failed = Signal()
    success = Signal()


    def __init__(self, local_path):
        super(ImageDownloadWorker, self).__init__()
        self.local_path = local_path
        self.url = '%s/get_image' % library_url
        self.chunk_size = 580

    @Slot()
    def run(self):

        data = dict(local_path=self.local_path)

        response = requests.post(
            self.url,
            data=json.dumps(data),
            headers={'Content-Type': 'application/json'},
            allow_redirects=False,
            stream=True
        )

        path = '%s%s' % (creaturecast_directory, self.local_path)

        if response.status_code == 200:
            dirname = os.path.dirname(path)
            try:
                os.makedirs(dirname)
            except:
                pass
            with open(path, 'wb') as f:
                response.raw.decode_content = True
                shutil.copyfileobj(response.raw, f)

            self.finished.emit(path)
            self.success.emit()
        else:
            self.failed.emit()




from github import Github

g = Github("paxtongerrish@gmail.com", "y25H{9(]GW7423z")
paxton = g.get_user()
for owned_repo in paxton.get_repos(type='owner'):
    default_branch = owned_repo.get_branch(owned_repo.default_branch)


#for repo in g.get_user().get_repos():
#    print repo.name
#    repo.edit(has_wiki=False)